@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.16';
+our $VERSION = '0.79';
 
 use Module::Runtime qw( use_module );
 use String::RewritePrefix;
@@ -46,3 +46,39 @@ sub provide_license {
 __PACKAGE__->meta->make_immutable;
 
 1;
+
+# ABSTRACT: Sets up default license and copyright holder
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Dist::Zilla::Plugin::MAXMIND::License - Sets up default license and copyright holder
+
+=head1 VERSION
+
+version 0.79
+
+=for Pod::Coverage .*
+
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/Dist-Zilla-PluginBundle-MAXMIND/issues>.
+
+=head1 AUTHOR
+
+Dave Rolsky <autarch@urth.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2017 by Dave Rolsky and MaxMind, Inc.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0 (GPL Compatible)
+
+=cut
